package com.dickimawbooks.jmakepdfx;

import java.awt.*;
import java.io.*;
import java.net.*;
import java.awt.event.*;
import javax.swing.*;

public class JpdfxResources
{
    public static void error(Component parent, String message)
    {
       Jmakepdfx.debug("Error: '"+message+"'");
       JOptionPane.showMessageDialog(parent, getMessagePane(message),
          Jmakepdfx.getLabelWithAlt("error.title", "Error"),
          JOptionPane.ERROR_MESSAGE);
    }

    public static void error(Component parent, Exception e)
    {
       String message = e.getMessage();
       Jmakepdfx.debug("Exception: "+e.getClass().toString()+" '"+message+"'");

       if (message != null)
       {
          JOptionPane.showMessageDialog(parent, getMessagePane(message),
             Jmakepdfx.getLabelWithAlt("error.title", "Error"),
            JOptionPane.ERROR_MESSAGE);
       }

       e.printStackTrace();
    }

    public static void warning(Component parent, String message)
    {
       Jmakepdfx.debug("Warning: '"+message+"'");
       JOptionPane.showMessageDialog(parent,
          getMessagePane(message),
          Jmakepdfx.getLabelWithAlt("error.warning", "Warning"),
          JOptionPane.WARNING_MESSAGE);
    }

    public static JButton createContinueButton(ActionListener listener)
    {
       return createContinueButton(listener, null);
    }

    public static JButton createContinueButton(ActionListener listener, String tooltipText)
    {
       return createActionButton(
          Jmakepdfx.getLabel("button.continue"),
          Jmakepdfx.getMnemonic("button.continue"),
          "okay", listener,
          KeyStroke.getKeyStroke(KeyEvent.VK_ENTER, 0), tooltipText);
    }

    public static JButton createOkayButton(ActionListener listener)
    {
       return createOkayButton(listener, null);
    }

    public static JButton createOkayButton(ActionListener listener, String tooltipText)
    {
       return createActionButton(
          Jmakepdfx.getLabel("button.okay"),
          Jmakepdfx.getMnemonic("button.okay"),
          "okay", listener,
          KeyStroke.getKeyStroke(KeyEvent.VK_ENTER, 0), tooltipText);
    }

    public static JButton createCancelButton(ActionListener listener)
    {
       return createCancelButton(listener, null);
    }

    public static JButton createCancelButton(ActionListener listener, String tooltipText)
    {
       return createActionButton(
          Jmakepdfx.getLabel("button.cancel"),
          Jmakepdfx.getMnemonic("button.cancel"),
          "cancel", listener,
          KeyStroke.getKeyStroke(KeyEvent.VK_ESCAPE, 0), tooltipText);
    }

    public static JButton createActionButton(String label, char mnemonic,
      String actionCommand, ActionListener listener, KeyStroke keyStroke, 
      String tooltipText)
    {
       JButton button = new JButton(label);
       button.setMnemonic(mnemonic);

       if (listener != null)
       {
          button.addActionListener(listener);

          if (actionCommand != null)
          {
             button.setActionCommand(actionCommand);

             if (keyStroke != null)
             {
                button.registerKeyboardAction(listener, actionCommand, keyStroke,
                  JComponent.WHEN_IN_FOCUSED_WINDOW);
             }
          }
       }

       if (tooltipText != null)
       {
          button.setToolTipText(tooltipText);
       }

       return button;
    }

    private static JTextArea createMessageArea()
    {
       JTextArea area = new JTextArea(4, 30);
       area.setWrapStyleWord(true);
       area.setLineWrap(true);
       area.setEditable(false);
       area.setBorder(null);
       area.setOpaque(false);

       return area;
    }

    private static Component getMessagePane(String message)
    {
       messageArea.setText(message);
       JScrollPane sp = new JScrollPane(messageArea);
       sp.setBorder(null);
       sp.setOpaque(false);

       return sp;
    }

    private static JTextArea messageArea = createMessageArea();
}
